@@ -769,7 +769,7 @@ cmc__update_replica_rds <- function(self, private, alert) {
   if (length(data_list) == 0) stop("No metadata available")
 
   private$data <- merge_packages_data(.list = data_list)
-  saveRDS(private$data, file = rep_files$rds, version = 2)
+  save_rds(private$data, rep_files$rds)
   private$data_time <- file_get_time(rep_files$rds)
   private$data_messaged <- NULL
 
